# geometryhelper
 
Простая библиотека Python для работы с геометрическими фигурами и с квадратичными уравнениями.

 solve_quadratic(a: float, b: float, c: float) -> Union[Tuple[float, float], Tuple[float], None]:    
 Эта функция решает квадратное уравнение вида ax^2 + bx + c = 0.

circle_area(radius: float) -> float:  
     Эта функция вычисляет площадь круга.

rectangle_area(length: float, width: float) -> float:  
     Эта функция вычисляет площадь прямоугольника.
## Установка
```bash
pip install geometryhelper